@@ -8,7 +8,7 @@ from imaxt_mosaic.settings import Settings
 from owl_dev import pipeline
 from owl_dev.logging import logger
 
-from ..utils import update_config
+from ..utils import cleanup, initialize, update_config
 
 
 class SettingsPlugin(WorkerPlugin):
@@ -44,25 +44,33 @@ def main(
     client.register_worker_plugin(SettingsPlugin(stitcher, config))
     update_config(stitcher, config)
 
-    if "calibration" in recipes:
-        logger.info("Running calibration recipe")
-        from ..calibration import compute_calibrations
+    initialize(output_path)
 
-        compute_calibrations(input_path, output_path, overwrite)
+    try:
+        if "calibration" in recipes:
+            logger.info("Running calibration recipe")
+            from ..calibration import compute_calibrations
 
-    if "mosaic" in recipes:
-        logger.info("Running mosaic recipe")
-        from ..stitchlib import imaxt_stitch
+            compute_calibrations(input_path, output_path, overwrite)
 
-        imaxt_stitch(input_path, output_path, stitcher, overwrite)
+        if "mosaic" in recipes:
+            logger.info("Running mosaic recipe")
+            from ..stitchlib import imaxt_stitch
 
-    if "mosaic_preview" in recipes:
-        logger.info("Running mosaic preview recipe")
-        from ..tileset import create_tileset
+            imaxt_stitch(input_path, output_path, stitcher, overwrite)
 
-        create_tileset(output_path, "tileset")
+        if "mosaic_preview" in recipes:
+            logger.info("Running mosaic preview recipe")
+            from ..tileset import create_tileset
 
-    if "bead_find" in recipes:
-        logger.critical("Bead finding recipe not implemented")
+            create_tileset(output_path, "tileset")
+
+        if "bead_detect" in recipes:
+            logger.info("Running bead_detection recipe")
+            from ..bead_detect.runner import bead_detect
+
+            bead_detect(output_path, overwrite=overwrite, fig=True)
+    finally:
+        cleanup(output_path)
 
     logger.info("Finished pipeline")
