@@ -2,7 +2,7 @@ from pathlib import Path
 
 import voluptuous as vo
 
-DEFAULT_RECIPES = ["calibration", "mosaic", "mosaic_preview", "bead_find"]
+DEFAULT_RECIPES = ["calibration", "mosaic", "mosaic_preview", "bead_detect"]
 STITCHER_NAMES = ["stpt", "axio"]
 
 
